cd "C:\Users\R500\Box Sync\Policy Evaluation\estimation"
use hh_98.dta, clear
log using psm_manual.smcl, replace

*This code was simplified from Cameron and Trivedi (2005)'s 
*Microeconometrics: Methods and Applications for demonstration

gen lexptot=ln(1+exptot)

*step 1: estimate propensity score
logit dfmfd sexhead agehead educhead vaccess pcirr rice wheat milk oil [pw=weight]
predict PSCORE

*step 2: create common support
sum PSCORE if dfmfd==1
scalar PTMIN = r(min)
scalar PTMAX = r(max)

sum PSCORE if dmmfd==0
scalar PCMIN = r(min)
scalar PCMAX = r(max)

drop if PSCORE < PTMIN
drop if PSCORE < PCMIN
drop if PSCORE > PTMAX
drop if PSCORE > PCMAX

sum PSCORE

*Check the common support
graph twoway (kdensity PSCORE if dfmfd==1, lpattern(longdash)) ///
(kdensity PSCORE if dfmfd==0, lpattern(shortdash)), ///
legend(label(1 "Treatment") label(2 "Control")) ///
bgcolor(white) graphregion(color(white)) ///
ytitle("Density") xtitle("Estimated Propensity Score")

*divide PSCORE into blocks and check balances within blocks
global cut1 = 0.2
global cut2 = 0.3
global cut3 = 0.4

gen myblock = 1
replace myblock = 2 if PSCORE > $cut1 & PSCORE < $cut2
replace myblock = 3 if PSCORE > $cut2 & PSCORE < $cut3
replace myblock = 4 if PSCORE > $cut3

tab myblock
tab myblock dfmfd, sum(agehead) nostand nofreq

*check balances in covariates
foreach i of numlist 1 2 3 4 {
ttest agehead if myblock==`i', by(dfmfd)
}

*step 3: calculate ATT by stratification weighing
keep lexptot exptot dfmfd PSCORE myblock
sort myblock PSCORE dfmfd

local i=1
while `i' <= 4 {
*reg exptot dmmfd PSCORE if myblock==`i'
reg lexptot dfmfd PSCORE if myblock==`i'
di "BLOCK " `i'
di "ATT"`i' " = " _b[dfmfd] 
di "SE " _se[dfmfd]
di "t-stat = " _b[dfmfd]/_se[dfmfd]
local ++i
}

*weighing ATT by block size

clear
log close
