cd "C:\Users\R500\Box Sync\Policy Evaluation\estimation"
use hh_9198_2018.dta, clear
log using did.smcl, replace

***************************************
***----------- Pooled OLS ----------***
***************************************

gen lexptot=ln(1+exptot)
gen lnland=ln(1+hhland/100)

*Create compatibale data

egen dmmfd98=max(dmmfd), by(nh)

gen dmmfdyr=dmmfd98*year

****Basic model
reg lexptot year dmmfd98 dmmfdyr

****Full model
reg lexptot year dmmfd98 dmmfdyr sexhead agehead educhead lnland vaccess pcirr rice wheat milk oil egg [pw=weight]


***************************************
***-------- PANEL REGRESSION -------***
***************************************

****Fixed effects: Basic
xtreg lexptot year dmmfd, fe i(nh)

****Fixed effects: Full Model
xtreg lexptot year dmmfd sexhead agehead educhead lnland vaccess pcirr rice wheat milk oil egg, fe i(nh)

****Alternative ways: Using LSDV instead of xtreg

areg lexptot year dmmfd, a(nh)

reg lexptot year dmmfd i.nh

areg lexptot year dmmfd sexhead agehead educhead lnland vaccess pcirr rice wheat milk oil egg, a(nh)

reg lexptot year dmmfd sexhead agehead educhead lnland vaccess pcirr rice wheat milk oil egg i.nh

****Regression using first differences

*--- USING THE ORIGINAL DATA---*
use hh_9198_2018.dta, clear

gen lexptot=ln(1+exptot)
gen lnland=ln(1+hhland/100)

*Reorganize the data from long to wide format
reshape wide villid-lnland, i(nh) j(year)

*Create differencing variables
gen dlexptot = lexptot1 - lexptot0
gen ddmmfd = dmmfd1 - dmmfd0

*Basic model
reg dlexptot ddmmfd

*Full model

local varName sexhead agehead educhead lnland vaccess pcirr rice wheat milk oil egg

foreach i of local varName {

gen d`i' = `i'1 - `i'0

}

reg dlexptot ddmmfd dsexhead dagehead deduchead dlnland dvaccess dpcirr drice dwheat dmilk doil degg

*---Taking into account the initial conditions

reg dlexptot ddmmfd dsexhead dagehead deduchead dlnland dvaccess dpcirr drice dwheat dmilk doil degg sexhead0 agehead0 educhead0 lnland0 vaccess0 pcirr0 rice0 wheat0 milk0 oil0 egg0

****DID combined with PSM

*--- USING THE ORIGINAL DATA---*
use hh_9198_2018.dta, clear

*Reorganize the data from long to wide format
reshape wide villid-dmmfd, i(nh) j(year)

pscore dmmfd1 sexhead0 agehead0 educhead0 hhland0 vaccess0 pcirr0 rice0 wheat0 milk0 oil0 egg0, pscore(score) blockid(block) comsup level(0.001)

*keep observations in common support
keep if comsup==1

*keep observation ID only
keep nh

*merge to the original dataset
merge nh using hh_9198_2018.dta

*keep only observations which matched the ID identified above
tab _merge
keep if _merge==3
drop _merge

*Estimate DiD model with panel data and fixed effects
gen lexptot=ln(1+exptot)
gen lnland=ln(1+hhland/100)

xtreg lexptot year dmmfd sexhead agehead educhead lnland vaccess pcirr rice wheat milk oil egg, fe i(nh)

clear
log close
